@@ -17,12 +17,11 @@
 #include <sys/un.h>
 
 #include <QFile>
+#include <QProcess>
 #include <QRegularExpression>
 #include <QStandardPaths>
 #include <qplatformdefs.h>
 
-#include <KToolInvocation>
-
 extern int kdesuDebugArea();
 
 namespace KDESu
@@ -163,8 +162,7 @@ QByteArray KDEsuClient::escape(const QByteArray &str)
     QByteArray copy;
     copy.reserve(str.size() + 4);
     copy.append('"');
-    for (int i = 0; i < str.size(); i++) {
-        uchar c = str.at(i);
+    for (const uchar c : str) {
         if (c < 32) {
             copy.append('\\');
             copy.append('^');
@@ -230,9 +228,9 @@ int KDEsuClient::exec(const QByteArray &prog, const QByteArray &user, const QByt
     if (!options.isEmpty() || !env.isEmpty()) {
         cmd += ' ';
         cmd += escape(options);
-        for (int i = 0; i < env.count(); ++i) {
+        for (const auto &var : env) {
             cmd += ' ';
-            cmd += escape(env.at(i));
+            cmd += escape(var);
         }
     }
     cmd += '\n';
@@ -305,7 +303,8 @@ QList<QByteArray> KDEsuClient::getKeys(const QByteArray &group)
     cmd += '\n';
     QByteArray reply;
     command(cmd, &reply);
-    int index = 0, pos;
+    int index = 0;
+    int pos;
     QList<QByteArray> list;
     if (!reply.isEmpty()) {
         while (1) {
@@ -383,7 +382,7 @@ int KDEsuClient::stopServer()
 
 static QString findDaemon()
 {
-    QString daemon = QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF5 "/kdesud");
+    QString daemon = QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR_KF "/kdesud");
     if (!QFile::exists(daemon)) { // if not in libexec, find it in PATH
         daemon = QStandardPaths::findExecutable(QStringLiteral("kdesud"));
         if (daemon.isEmpty()) {
@@ -425,13 +424,15 @@ int KDEsuClient::startServer()
                            << "kdesud not setgid!";
     }
 
-    // kdesud only forks to the background after it is accepting
-    // connections.
-    // We start it via kdeinit to make sure that it doesn't inherit
-    // any fd's from the parent process.
-    int ret = KToolInvocation::kdeinitExecWait(d->daemon);
+    QProcess proc;
+    proc.start(d->daemon, QStringList{});
+    if (!proc.waitForFinished()) {
+        qCCritical(KSU_LOG) << "Couldn't start kdesud!";
+        return -1;
+    }
+
     connect();
-    return ret;
+    return proc.exitCode();
 }
 
 } // namespace KDESu
